pyDocsis: A library for doing things to DOCSIS configs with python
=========

A few python files for reading, modifying, and creating DOCSIS files.

It *mostly* works! Mibs need some more testing and TLV7 assumes that your CMTS is going to strip out that value and replace it with something else. See te Docs folder for examples.